/*! Primary plugin JavaScript. * @since 1.0.0 * @package Directly Import */

/**
 * WordPress AJAX URL.
 * 
 * @since 1.0.0
 * 
 * @var string
 */
var ajaxurl = ajaxurl || '';

/**
 * Current WordPress admin page ID.
 * 
 * @since 1.0.0
 * 
 * @var string
 */
var pagenow = pagenow || '';

/**
 * WordPress postboxes object.
 * 
 * @since 1.0.0
 * 
 * @var object
 */
var postboxes = postboxes || {};

/**
 * Options object.
 * 
 * @since 1.0.0
 * 
 * @var object
 */
var diim_script_options = diim_script_options || {};

/**
 * Validation rules object.
 * 
 * @since 1.0.0
 * 
 * @var object
 */
var diim_script_validation = diim_script_validation || {};

(function ($)
{
	'use strict';

	$(document)
	.ready(function ()
	{
		$.fn.extend(
		{
			/**
			 * Add a custom event to all provided elements.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.fn.diim_add_event
			 * @this   object     Elements to add the event to.
			 * @param  string   e Event name to add to all elements.
			 * @param  function f Function executed when the event is fired.
			 * @return object     Updated elements.
			 */
			"diim_add_event": function (e, f)
			{
				return this.addClass(e).on(e, f).diim_trigger_all(e);
			},

			/**
			 * Fire an event on all provided elements.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.fn.diim_trigger_all
			 * @this   object      Elements to fire the event on.
			 * @param  string e    Event name to fire on all elements.
			 * @param  array  args Extra arguments to pass to the event call.
			 * @return object      Triggered elements.
			 */
			"diim_trigger_all": function (e, args)
			{
				args = ($.type(args) === 'undefined')
				? []
				: args;

				if (!$.isArray(args))
				{
					args = [args];
				}

				return this
				.each(function ()
				{
					$(this).triggerHandler(e, args);
				});
			}
		});

		/**
		 * General variables.
		 * 
		 * @since 1.0.0
		 * 
		 * @access jQuery.directly_import
		 * @var    object
		 */
		$.directly_import = $.directly_import || {};
		
		var diim = $.directly_import;

		$.extend(diim,
		{
			/**
			 * WordPress admin bar layer.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.admin_bar
			 * @var    object
			 */
			"admin_bar": $('#wpadminbar'),
			
			/**
			 * Current document BODY layer.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.body
			 * @var    object
			 */
			"body": $(document.body),
			
			/**
			 * Current document object.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.document
			 * @var    object
			 */
			"document": $(document),
			
			/**
			 * Current window object.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.window
			 * @var    object
			 */
			"window": $(window),
			
			/**
			 * Options object.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.options
			 * @var    object
			 */
			"options": diim_script_options || {},
			
			/**
			 * Validation rules object.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.validation
			 * @var    object
			 */
			"validation": diim_script_validation || {},
			
			/**
			 * Current top scroll position.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.scroll_top
			 * @var    integer
			 */
			"scroll_top": 0,

			/**
			 * Layers used for scrolling.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.scroll_element
			 * @var    object
			 */
			"scroll_element": $('html,body')
			.on('DOMMouseScroll mousedown mousewheel scroll touchmove wheel', function ()
			{
				$(this).stop();
			})
		});
		
		/**
		 * Options object.
		 * 
		 * @since 1.0.0
		 * 
		 * @access jQuery.directly_import.options
		 * @var    object
		 */
		var diimo = diim.options || {};

		/**
		 * Validation rules object.
		 * 
		 * @since 1.0.0
		 * 
		 * @access jQuery.directly_import.validation
		 * @var    object
		 */
		var diimv = diim.validation || {};
		
		/**
		 * Data variable names.
		 * 
		 * @since 1.0.0
		 * 
		 * @access jQuery.directly_import.data
		 * @var    object
		 */
		diim.data = diim.data || {};
		
		var diimd = diim.data;
		
		$.extend(diimd,
		{
			/**
			 * Compare operator used for a field being compared for a conditional field.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.compare
			 * @var    string
			 */
			"compare": 'diim-compare',

			/**
			 * Name for a conditional field.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.conditional
			 * @var    string
			 */
			"conditional": 'diim-conditional',

			/**
			 * Name of the field being compared for a conditional field.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.field
			 * @var    string
			 */
			"field": 'diim-field',
			
			/**
			 * AJAX action for import buttons.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.import_action
			 * @var    string
			 */
			"import_action": 'diim-import-action',

			/**
			 * Initial value for a form field.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.initial_value
			 * @var    string
			 */
			"initial_value": 'diim-initial-value',

			/**
			 * Post type to import.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.post_type
			 * @var    string
			 */
			"post_type": 'diim-post-type',
			
			/**
			 * URL for export sites.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.url
			 * @var    string
			 */
			"url": 'diim-url',

			/**
			 * Value to check for a field being compared for a conditional field.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.data.value
			 * @var    string
			 */
			"value": 'diim-value'
		});
		
		/**
		 * Event names.
		 * 
		 * @since 1.0.0
		 * 
		 * @access jQuery.directly_import.events
		 * @var    object
		 */
		diim.events = diim.events || {};
		
		var diime = diim.events;
		
		$.extend(diime,
		{
			/**
			 * Event used to check for field conditions.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.events.check_conditions
			 * @var    string
			 */
			"check_conditions": 'diim-check-conditions'
		});

		if (diimo.has_form)
		{
			/**
			 * Fields JSON object.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.forms
			 * @var    object
			 */
			diim.fields = diim.fields || {};

			var diimfi = diim.fields;

			$.extend(diimfi,
			{
				/**
				 * Prepare fields with conditional logic.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.fields.conditional
				 * @return void
				 */
				"conditional": function ()
				{
					$('.diim-condition[data-' + diimd.conditional + '][data-' + diimd.field + '][data-' + diimd.value + '][data-' + diimd.compare + ']')
					.each(function ()
					{
						var condition = $(this);
						var conditional = $('[name="' + condition.data(diimd.conditional) + '"],[data-' + diimd.name + '="' + condition.data(diimd.conditional) + '"]');
						var field = $('[name="' + condition.data(diimd.field) + '"]');

						if
						(
							!conditional.hasClass(diime.check_conditions)
							&&
							field.length > 0
						)
						{
							conditional
							.diim_add_event(diime.check_conditions, function ()
							{
								var current_conditional = $(this);
								var show_field = true;

								var conditional_name = (current_conditional.is('[name]'))
								? current_conditional.attr('name')
								: current_conditional.data(diimd.name);

								$('.diim-condition[data-' + diimd.conditional + '="' + conditional_name + '"][data-' + diimd.field + '][data-' + diimd.value + '][data-' + diimd.compare + ']')
								.each(function ()
								{
									var current_condition = $(this);
									var current_field = $('[name="' + current_condition.data(diimd.field) + '"]');
									var compare = current_condition.data(diimd.compare);
									var compare_matched = false;

									var current_value = (current_field.is(':radio'))
									? current_field.filter(':checked').val()
									: current_field.val();

									if (current_field.is(':checkbox'))
									{
										current_value = (current_field.is(':checked'))
										? current_value
										: '';
									}

									if (compare === '!=')
									{
										compare_matched = (current_condition.data(diimd.value) + '' !== current_value + '');
									}
									else
									{
										compare_matched = (current_condition.data(diimd.value) + '' === current_value + '');
									}

									show_field =
									(
										show_field
										&&
										compare_matched
									);
								});

								var parent = current_conditional.closest('.diim-field');
								parent.next('.diim-field-spacer').remove();

								if (show_field)
								{
									parent.stop(true).slideDown('fast');
								}
								else
								{
									parent.stop(true).slideUp('fast').after($('<div/>').addClass('diim-hidden diim-field-spacer'));
								}
							});
						}

						if (!field.hasClass('diim-has-condition'))
						{
							field.addClass('diim-has-condition')
							.on('change', function ()
							{
								$('.diim-condition[data-' + diimd.conditional + '][data-' + diimd.field + '="' + $(this).attr('name') + '"][data-' + diimd.value + '][data-' + diimd.compare + ']')
								.each(function ()
								{
									$('[name="' + $(this).data(diimd.conditional) + '"],[data-' + diimd.name + '="' + condition.data(diimd.conditional) + '"]').diim_trigger_all(diime.check_conditions);
								});
							});
						}
					});
				}
			});

			/**
			 * Buttons JSON object.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.buttons
			 * @var    object
			 */
			diim.buttons = diim.buttons || {};

			var diimb = diim.buttons;

			$.extend(diimb,
			{
				/**
				 * Prepare the add site button.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.buttons.add_site
				 * @return void
				 */
				"add_site": function ()
				{
					$('.diim-add-site')
					.click(function ()
					{
						var clicked = $(this);
						var form = clicked.closest('form');
						
						if (form.valid())
						{
							clicked.addClass('diim-clicked');
							
							var buttons = form.find('.diim-button:not([disabled])').prop('disabled', true);

							$.post(
							{
								"url": diimo.ajaxurl,

								"data":
								{
									"action": 'diim_add_site',
									"url": form.find('input[name="add_site"]').val()
								},

								"error": function ()
								{
									buttons.prop('disabled', false);
								},

								"success": function (response)
								{
									if
									(
										response
										&&
										response.success
									)
									{
										window.location.reload();
									}
									else
									{
										clicked.removeClass('diim-clicked');
										buttons.prop('disabled', false);
									}
								}
							});
						}
					});
				},
				
				/**
				 * Prepare the archive site buttons.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.buttons.archive_site
				 * @return void
				 */
				"archive_site": function ()
				{
					$('.diim-archive-site')
					.click(function ()
					{
						var clicked = $(this).addClass('diim-clicked');
						var meta_box = clicked.closest('.diim-meta-box');
						var buttons = $('.diim-button:not([disabled])').prop('disabled', true);

						$.post(
						{
							"url": diimo.ajaxurl,

							"data":
							{
								"action": 'diim_archive_site',
								"url": meta_box.find('.diim-site-url').val()
							},

							"error": function ()
							{
								buttons.prop('disabled', false);
							},

							"success": function (response)
							{
								if
								(
									response
									&&
									response.success
								)
								{
									window.location.reload();
								}
								else
								{
									clicked.removeClass('diim-clicked');
									buttons.prop('disabled', false);
								}
							}
						});
					});
				},
				
				/**
				 * Setup the copy to clipboard button.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.buttons.copy_to_clipboard
				 * @return void
				 */
				"copy_to_clipboard": function ()
				{
					$('.diim-copy-to-clipboard')
					.click(function ()
					{
						var clicked = $(this);
						var pre = clicked.closest('div').find('pre').first();

						if
						(
							!clicked.hasClass('diim-clicked')
							&&
							pre.length > 0
						)
						{
							clicked.addClass('diim-clicked');
							
							setTimeout(function ()
							{
								clicked.removeClass('diim-clicked');
							},
							800);
							
							var range;
							
							if (document.body.createTextRange)
							{
								range = document.body.createTextRange();
								range.moveToElementText(pre.get(0));
								range.select();
							}
							else if (window.getSelection)
							{
								var selection = window.getSelection();
								
								range = document.createRange();
								range.selectNodeContents(pre.get(0));

								selection.removeAllRanges();
								selection.addRange(range);
							}

							document.execCommand('copy');
						}
					});
				},
				
				/**
				 * Prepare the delete site buttons.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.buttons.delete_site
				 * @return void
				 */
				"delete_site": function ()
				{
					$('.diim-delete-site[data-' + diimd.url + ']')
					.click(function ()
					{
						if (confirm(diimo.strings.delete_site))
						{
							var clicked = $(this).addClass('diim-clicked');
							var buttons = $('.diim-button:not([disabled])').prop('disabled', true);

							$.post(
							{
								"url": diimo.ajaxurl,

								"data":
								{
									"action": 'diim_delete_site',
									"url": clicked.data(diimd.url)
								},

								"error": function ()
								{
									buttons.prop('disabled', false);
								},

								"success": function (response)
								{
									if
									(
										response
										&&
										response.success
									)
									{
										window.location.reload();
									}
									else
									{
										clicked.removeClass('diim-clicked');
										buttons.prop('disabled', false);
									}
								}
							});
						}
					});
				},
				
				/**
				 * Prepare the import action buttons.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.buttons.import_action
				 * @return void
				 */
				"import_action": function ()
				{
					$('.diim-ajax-button[data-' + diimd.import_action + ']')
					.click(function (e, continued)
					{
						var clicked = $(this);
						
						if
						(
							continued === true
							||
							!clicked.hasClass('diim-import-button')
							||
							confirm(diimo.strings.import)
						)
						{
							clicked.addClass('diim-clicked');
							
							var meta_box = clicked.closest('.diim-meta-box');
							var buttons = $('.diim-button:not([disabled])').prop('disabled', true);
							
							var data =
							{
								"action": 'diim_import_action',
								"import_action": clicked.data(diimd.import_action),
								"url": meta_box.find('.diim-site-url').val()
							};
							
							if (clicked.is('[data-' + diimd.post_type + ']'))
							{
								data.post_type = clicked.data(diimd.post_type);
							}

							$.post(
							{
								"data": data,
								"url": diimo.ajaxurl,
								
								"error": function ()
								{
									buttons.prop('disabled', false);
								},

								"success": function (response)
								{
									if
									(
										response
										&&
										response.success
									)
									{
										if (response.imported)
										{
											$.each(response.imported, function (index, value)
											{
												var label = $('.diim-post-type-' + index);
												
												if (label.length > 0)
												{
													label.text(parseInt(label.text()) + value);
												}
											});
										}
										
										if (response.continue)
										{
											buttons.prop('disabled', false);
											clicked.triggerHandler('click', [true]);
										}
										else
										{
											window.location.reload();
										}
									}
									else
									{
										clicked.removeClass('diim-clicked');
										buttons.prop('disabled', false);
									}
								}
							});
						}
					});
				},
				
				/**
				 * Prepare the regenerate API key button.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.buttons.regenerate_api_key
				 * @return void
				 */
				"regenerate_api_key": function ()
				{
					$('.diim-regenerate-api-key')
					.click(function ()
					{
						var clicked = $(this).addClass('diim-clicked');
						var buttons = $('.diim-button:not([disabled])').prop('disabled', true);
						
						$.post(
						{
							"url": diimo.ajaxurl,
							
							"data":
							{
								"action": 'diim_regenerate_api_key'
							},
							
							"error": function ()
							{
								buttons.prop('disabled', false);
							},
							
							"success": function (response)
							{
								if
								(
									response
									&&
									response.success
								)
								{
									$('input.diim-api-key').val(response.api_key);
									
									clicked.closest('div').find('pre').text(response.url);
								}
								
								clicked.removeClass('diim-clicked');
								buttons.prop('disabled', false);
							}
						});
					});
				},
				
				/**
				 * Prepare the restore site buttons.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.buttons.restore_site
				 * @return void
				 */
				"restore_site": function ()
				{
					$('.diim-restore-site[data-' + diimd.url + ']')
					.click(function ()
					{
						var clicked = $(this).addClass('diim-clicked');
						var buttons = $('.diim-button:not([disabled])').prop('disabled', true);

						$.post(
						{
							"url": diimo.ajaxurl,

							"data":
							{
								"action": 'diim_restore_site',
								"url": clicked.data(diimd.url)
							},

							"error": function ()
							{
								buttons.prop('disabled', false);
							},

							"success": function (response)
							{
								if
								(
									response
									&&
									response.success
								)
								{
									window.location.reload();
								}
								else
								{
									clicked.removeClass('diim-clicked');
									buttons.prop('disabled', false);
								}
							}
						});
					});
				}
			});
			
			diimb.add_site();
			diimb.archive_site();
			diimb.copy_to_clipboard();
			diimb.delete_site();
			diimb.import_action();
			diimb.regenerate_api_key();
			diimb.restore_site();
			
			/**
			 * Forms JSON object.
			 * 
			 * @since 1.0.0
			 * 
			 * @access jQuery.directly_import.forms
			 * @var    object
			 */
			diim.forms = diim.forms || {};

			var diimfo = diim.forms;

			$.extend(diimfo,
			{
				/**
				 * True if changes have been made to the form.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.forms.changes_made
				 * @var    boolean
				 */
				"changes_made": false,
				
				/**
				 * Setup the before upload event.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.forms.before_unload
				 * @return void
				 */
				"before_unload": function ()
				{
					diim.window
					.on('beforeunload', function ()
					{
						if (diimfo.changes_made)
						{
							return diimo.strings.save_alert;
						}
					});
				},

				/**
				 * Setup the form fields.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.forms.fields
				 * @return void
				 */
				"fields": function ()
				{
					$('.diim-form').find('input,select,textarea').not('.diim-ignore-change')
					.each(function ()
					{
						var current = $(this);
						current.data(diimd.initial_value, current.val());
					})
					.change(function ()
					{
						var changed = $(this);

						if (changed.val() != changed.data(diimd.initial_value))
						{
							diimfo.changes_made = true;
						}
					});

					diimfi.conditional();
				},
				
				/**
				 * Include postboxes functionality.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.forms.postboxes
				 * @return void
				 */
				"postboxes": function ()
				{
					if
					(
						$.type(postboxes) !== 'undefined'
						&&
						!$.isEmptyObject(postboxes)
						&&
						$.type(pagenow) !== 'undefined'
					)
					{
						$('.if-js-closed').removeClass('if-js-closed').not('.diim-meta-box-locked').addClass('closed');

						postboxes.add_postbox_toggles(pagenow);

						$('.diim-meta-box-locked')
						.each(function ()
						{
							var current = $(this);
							current.find('.handlediv').remove();
							current.find('.hndle').off('click.postboxes');

							var hider = $('#' + current.attr('id') + '-hide');

							if (!hider.is(':checked'))
							{
								hider.click();
							}

							hider.parent().remove();
						});
					}
				},

				/**
				 * Setup the form validation.
				 * 
				 * @since 1.0.0
				 * 
				 * @access jQuery.directly_import.forms.validation
				 * @return void
				 */
				"validation": function ()
				{
					$('.diim-form')
					.each(function ()
					{
						$(this)
						.validate(
						{
							"focusInvalid": false,
							"rules": diimv,

							"errorPlacement": function (error, element)
							{
								error.hide().insertAfter(element).slideDown('fast');
							},

							"invalidHandler": function (e, validator)
							{
								if (!validator.numberOfInvalids())
								{
									return;
								}

								var element = $(validator.errorList[0].element);
								var tab = element.closest('.diim-tab');

								if
								(
									tab.length > 0
									&&
									!tab.hasClass('.diim-tab-active')
								)
								{
									var tab_index = tab.parent().children('.diim-tab').index(tab);

									tab.closest('.diim-tabs').find('.diim-tab-buttons a').eq(tab_index).triggerHandler('click');
								}

								var admin_bar_height = diim.admin_bar.height();
								var window_height = diim.window.height() - admin_bar_height;
								var element_height = element.outerHeight();
								var scroll_top = element.offset().top - admin_bar_height;

								if (element_height < window_height)
								{
									scroll_top -= Math.floor((window_height - element_height - admin_bar_height) / 2);
								}

								diim.scroll_element
								.animate(
								{
									"scrollTop": Math.max(0, Math.min(diim.document.height() - window_height, scroll_top)) + 'px'
								},
								{
									"queue": false
								});
							},

							"showErrors": function()
							{
								$('.diim-notice.is-dismissible .notice-dismiss').diim_trigger_all('click');

								var message = $('.diim-notice.diim-validation-error');

								if
								(
									this.numberOfInvalids() > 0
									&&
									!message.hasClass('diim-invalid')
								)
								{
									message.stop(true).addClass('diim-invalid').slideDown('fast');
								}
								else if
								(
									this.numberOfInvalids() == 0
									&&
									message.hasClass('diim-invalid')
								)
								{
									message.stop(true).removeClass('diim-invalid').slideUp('fast');
								}

								this.defaultShowErrors();
							},

							"submitHandler": function (form)
							{
								var $form = $(form);
								$form.find('[type="submit"]').prop('disabled', true);

								diimfo.changes_made = false;

								form.submit();
							}
						});
					})
					.find('[type="submit"]')
					.click(function ()
					{
						var clicked = $(this).addClass('diim-clicked');
						clicked.closest('form').find('[type="submit"]').not(clicked).removeClass('diim-clicked');
					})
					.prop('disabled', false);
				}
			});

			diimfo.before_unload();
			diimfo.fields();
			diimfo.postboxes();
			diimfo.validation();
		}
	});
})(jQuery);
