<?php
/*!
 * Plugin Name: Directly Import
 * Plugin URI:  https://wordpress.org/plugins/directly-import/
 * Description: Import posts and media directly from another WordPress site.
 * Version:     1.0.0
 * Author:      Robert Noakes
 * Author URI:  https://robertnoakes.com/
 * Text Domain: directly-import
 * Domain Path: /languages/
 * Copyright:   (c) 2020 Robert Noakes (mr@robertnoakes.com)
 * License:     GNU General Public License v3.0
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 */
 
/**
 * Main plugin file.
 * 
 * @since 1.0.0
 * 
 * @package Directly Import
 */
 
if (!defined('ABSPATH'))
{
	exit;
}

/**
 * Setup autoloading for plugin classes.
 *
 * @since 1.0.0
 */
spl_autoload_register(function ($class)
{
	$base_class = 'Directly_Import';

	if (strpos($class, $base_class) === 0)
	{
		$includes_path = dirname(__FILE__) . '/includes/';
		$core_path = $includes_path . 'core/class-';
		$standalone_path = $includes_path . 'standalone/class-';
		$static_path = $includes_path . 'static/class-';

		$file_name = ($class == $base_class)
		? 'base'
		: strtolower(str_replace(array($base_class . '_', '_'), array('', '-'), $class));

		$file_name .= '.php';

		if (file_exists($core_path . $file_name))
		{
			require_once($core_path . $file_name);
		}
		else if (file_exists($standalone_path . $file_name))
		{
			require_once($standalone_path . $file_name);
		}
		else if (file_exists($static_path . $file_name))
		{
			require_once($static_path . $file_name);
		}
	}
	else if ($class == 'WP_Screen')
	{
		require_once(ABSPATH . 'wp-admin/includes/class-wp-screen.php');
	}
});

/**
 * Returns the main instance of Directly_Import.
 *
 * @since 1.0.0
 *
 * @param  string          $file Optional main plugin file name.
 * @return Directly_Import       Main Directly_Import instance.
 */
function Directly_Import($file = '')
{
	return Directly_Import::_get_instance($file);
}

register_activation_hook(__FILE__, array('Directly_Import_Setup', 'activate'));
register_deactivation_hook(__FILE__, array('Directly_Import_Setup', 'deactivate'));

Directly_Import(__FILE__);
