<?php
/*!
 * Global plugin hooks.
 *
 * @since 1.0.0
 *
 * @package    Directly Import
 * @subpackage Global
 */

if (!defined('ABSPATH'))
{
	exit;
}

/**
 * Class used to implement global hooks.
 *
 * @since 1.0.0
 */
final class Directly_Import_Global
{
	/**
	 * Add additional classes to the admin BODY tag.
	 * 
	 * @since 1.0.0
	 * 
	 * @access public static
	 * @param  string $classes Existing classes.
	 * @return string          Modified classes.
	 */
	public static function admin_body_class($classes)
	{
		global $wp_version;
		
		if (version_compare($wp_version, '5.3-dev', '>='))
		{
			$classes .= ' diim-wp-5-3';
		}

		return $classes;
	}
	
	/**
	 * Default scripts for form pages.
	 *
	 * @since 1.0.0
	 *
	 * @access public static
	 * @return void
	 */
	public static function admin_enqueue_scripts_form()
	{
		self::admin_enqueue_scripts_main();
		
		wp_localize_script
		(
			'diim-script',
			'diim_script_options',

			array
			(
				'ajaxurl' => admin_url('admin-ajax.php'),
				'has_form' => true,

				'strings' => array
				(
					'delete_site' => __('Are you sure you want to completely delete the site?', 'directly-import'),
					'import' => __('Are you sure you want to start importing?', 'directly-import'),
					'save_alert' => __('The changes you made will be lost if you navigate away from this page.', 'directly-import'),
					'unexpected' => __('An unexpected error has occurred.', 'directly-import')
				)
			)
		);
		
		wp_localize_script('diim-script', 'diim_script_validation', Directly_Import()->cache->form_validation);
	}
	
	/**
	 * Enqueue main plugin scripts and styles.
	 *
	 * @since 1.0.0
	 *
	 * @access public static
	 * @return void
	 */
	public static function admin_enqueue_scripts_main()
	{
		wp_deregister_script('jquery-validation');
		
		wp_dequeue_script('jquery-validation');
		
		wp_enqueue_script('postbox');
		wp_enqueue_script('wp-util');
		
		$diim = Directly_Import();
		$full_vendor_path = plugins_url('/assets/vendor/', $diim->plugin);
		
		$asset_suffix = ($diim->cache->script_debug)
		? ''
		: '.min';
		
		wp_enqueue_script('jquery-validation', $full_vendor_path . 'jquery-validation/jquery.validate' . $asset_suffix . '.js', array(), '1.19.1', true);
		
		$home_url = home_url();
		$vendor_path = str_replace($home_url, '', $full_vendor_path);
		$locale = get_locale();
		$locale_split = explode('_', $locale);
		$locale_hyphen = implode('-', $locale_split);
		
		$jquery_validation_path = $vendor_path . 'jquery-validation/localization/';
		$jquery_validation_messages_file = $jquery_validation_path . 'messages_' . $locale . '.min.js';
		$jquery_validation_messages_file_simple = $jquery_validation_path . 'messages_' . $locale_split[0] . '.min.js';

		if (file_exists(ABSPATH . $jquery_validation_messages_file))
		{
			wp_enqueue_script('jquery-validation-localization-messages', $home_url . $jquery_validation_messages_file, array(), '1.19.1', true);
		}
		else if (file_exists(ABSPATH . $jquery_validation_messages_file_simple))
		{
			wp_enqueue_script('jquery-validation-localization-messages', $home_url . $jquery_validation_messages_file_simple, array(), '1.19.1', true);
		}

		$jquery_validation_methods_file = $jquery_validation_path . 'methods_' . $locale . '.min.js';
		$jquery_validation_methods_file_simple = $jquery_validation_path . 'methods_' . $locale_split[0] . '.min.js';

		if (file_exists(ABSPATH . $jquery_validation_methods_file))
		{
			wp_enqueue_script('jquery-validation-localization-methods', $home_url . $jquery_validation_methods_file, array(), '1.19.1', true);
		}
		else if (file_exists(ABSPATH . $jquery_validation_methods_file_simple))
		{
			wp_enqueue_script('jquery-validation-localization-methods', $home_url . $jquery_validation_methods_file_simple, array(), '1.19.1', true);
		}
		
		wp_enqueue_style('diim-style', $diim->cache->asset_path('styles', 'style.css'), array('dashicons'), Directly_Import_Constants::VERSION);
		wp_enqueue_script('diim-script', $diim->cache->asset_path('scripts', 'script.js'), array('postbox', 'jquery-validation'), Directly_Import_Constants::VERSION, true);
	}
	
	/**
	 * Add the admin page tabs.
	 *
	 * @since 1.0.0
	 *
	 * @access public static
	 * @return void
	 */
	public static function admin_tabs()
	{
		if (!Directly_Import()->settings->disable_imports)
		{
			Directly_Import_Output::add_tab('options-general.php', Directly_Import_Constants::OPTION_SETTINGS, __('Settings', 'directly-import'));
			Directly_Import_Output::add_tab('tools.php', Directly_Import_Constants::OPTION_SITES, __('Import', 'directly-import'));
		}
	}
}
